==> redshift-jquery-2.0.0.tgz: package/redshift-jquery.global.js <==
(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
"use strict";

var plugin = require('./plugin.js');

// If both jQuery and Redshift are loaded globally, 
if (window.jQuery && window.redshift) {
    plugin.load(window.jQuery, window.redshift);
}
},{"./plugin.js":2}],2:[function(require,module,exports){
/*
    Redshift jQuery plugin
*/
"use strict";

var _jQuery, // Private instance of jQuery
    _redshift, // Private instance of Redshift

    ACTION = 'redshiftAction', // Data key for Action
    
    
    /*
        Generate a plugin function
        
        @param [string]: Method name to attach to jQuery and to call on Action
    */
    generateFunction = function (method) {
        _jQuery.fn[method] = function () {
            execute(this, arguments, method);
            return this;
        }
    },


    /*
        Get or create Action on jQuery element
        
        @param [jQuery selection]
        @return [Action]
    */
    getAction = function ($element) {
        var action = $element.data(ACTION);
        
        // If Action doesn't exist yet, create it
        if (!action) {
            // Create Action
            action = _redshift.newAction();
            
            // Change Action scope to jQuery element
            action.setProp('scope', $element);
            
            // Bind Action to jQuery element
            $element.data(ACTION, action);
        }
        
        return action;
    },


    /*
        Execute defined function
    */
    execute = function ($elements, args) {
        var argsLength = args.length,
            params = [],
            returnVal = [],
            methodIsNamed = (arguments.length === 3),
            method = methodIsNamed ? arguments[2] : args[0],
            argsIndex = methodIsNamed ? 0 : 1;

        // Build argument array
        for (var i = argsIndex; i < argsLength; i++) {
            params.push(args[i]);
        }

        // Loop through elements and fire each Action with arguments
        $elements.each(function () {
            var action = getAction($(this)),
                output = action[method].apply(action, params),
                thisReturn = (output == action) ? $(this) : output;
            
            returnVal.push(thisReturn);
        });
        
        // Return all elements if no return value, else return final value
        return (returnVal.length === 1) ? returnVal[0] : returnVal;
    };

module.exports = {
    
    /*
        Load Redshift jQuery plugin
        
        @param [jQuery]
        @param [Redshift]
    */
    load: function (JQ, RS) {
        _jQuery = JQ;
        _redshift = RS;
        
        /*
            Action plugin
            
            Usage
                $('.selector').action(); // Return the Action associated with this selector
                $('.selector').action('setProp', 'foo', 'bar'); // Call Action.setProp('foo', 'bar')
            
            @param [string]: Action function to call
            @param [...]: Subsequent arguments
            @return [jQuery || Action]
        */
        _jQuery.fn.action = function () {
            var returnVal;

            if (arguments.length) {
                returnVal = execute(this, arguments);
                
                if (returnVal === Action) {
                    returnVal = this;
                }
            } else {
                returnVal = getAction($(this));
            }
            
            return returnVal;
        };
        
        /*
            Main Action method plugins
            
            Usage
                $('.selector').play('yourPreset', { foo: bar });
        */
        generateFunction('play');
        generateFunction('track');
        generateFunction('run');
    }
};
},{}]},{},[1]);

==> redshift-jquery-3.0.0.tgz: package/redshift-jquery.global.js <==
(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
"use strict";

var plugin = require('./plugin.js');

// If both jQuery and Redshift are loaded globally, 
if (window.jQuery && window.redshift) {
    plugin.load(window.jQuery, window.redshift);
}
},{"./plugin.js":2}],2:[function(require,module,exports){
/*
    Redshift jQuery plugin
*/
"use strict";

var _jQuery, // Private instance of jQuery
    _redshift, // Private instance of Redshift

    ACTION = 'redshiftAction', // Data key for Action
    
    
    /*
        Generate a plugin function
        
        @param [string]: Method name to attach to jQuery and to call on Action
    */
    generateFunction = function (method) {
        _jQuery.fn[method] = function () {
            execute(this, arguments, method);
            return this;
        }
    },


    /*
        Get or create Action on jQuery element
        
        @param [jQuery selection]
        @return [Action]
    */
    getAction = function ($element) {
        var action = $element.data(ACTION);
        
        // If Action doesn't exist yet, create it
        if (!action) {
            // Create Action
            action = _redshift.newAction();
            
            // Change Action scope to jQuery element and add dom
            action
                .setProp('scope', $element)
                .setProp('dom', $element[0]);
            
            // Bind Action to jQuery element
            $element.data(ACTION, action);
        }
        
        return action;
    },


    /*
        Execute defined function
    */
    execute = function ($elements, args) {
        var argsLength = args.length,
            params = [],
            returnVal = [],
            methodIsNamed = (arguments.length === 3),
            method = methodIsNamed ? arguments[2] : args[0],
            argsIndex = methodIsNamed ? 0 : 1;

        // Build argument array
        for (var i = argsIndex; i < argsLength; i++) {
            params.push(args[i]);
        }

        // Loop through elements and fire each Action with arguments
        $elements.each(function () {
            var action = getAction($(this)),
                output = action[method].apply(action, params),
                thisReturn = (output == action) ? $(this) : output;
            
            returnVal.push(thisReturn);
        });
        
        // Return all elements if no return value, else return final value
        return (returnVal.length === 1) ? returnVal[0] : returnVal;
    };

module.exports = {
    
    /*
        Load Redshift jQuery plugin
        
        @param [jQuery]
        @param [Redshift]
    */
    load: function (JQ, RS) {
        _jQuery = JQ;
        _redshift = RS;
        
        /*
            Action plugin
            
            Usage
                $('.selector').action(); // Return the Action associated with this selector
                $('.selector').action('setProp', 'foo', 'bar'); // Call Action.setProp('foo', 'bar')
            
            @param [string]: Action function to call
            @param [...]: Subsequent arguments
            @return [jQuery || Action]
        */
        _jQuery.fn.action = function () {
            var returnVal;

            if (arguments.length) {
                returnVal = execute(this, arguments);
                
                if (returnVal === Action) {
                    returnVal = this;
                }
            } else {
                returnVal = getAction($(this));
            }
            
            return returnVal;
        };
        
        /*
            Main Action method plugins
            
            Usage
                $('.selector').play('yourPreset', { foo: bar });
        */
        generateFunction('play');
        generateFunction('track');
        generateFunction('run');
    }
};
},{}]},{},[1]);
